@@ -7,5 +7,5 @@ def import_from_path(path: str, name: str, module_name: str = '.') -> object:
 	spec = spec_from_file_location(module_name, path)
 	module = module_from_spec(spec)
 	spec.loader.exec_module(module)
-	assert name in module.__dict__, 'Name "%s" in path "%s" does not exist.' % (method, path)
+	assert name in module.__dict__, 'Name "%s" in path "%s" does not exist.' % (name, path)
 	return module.__dict__[name]
\ No newline at end of file
